<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Rename</source>
        <translation>Nimeä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Move</source>
        <translation>Siirrä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Share</source>
        <translation>Jaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Compress</source>
        <translation>Pakkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Documents</source>
        <translation>Dokumentit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Images</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Sounds</source>
        <translation>Äänet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Added to Clipboard</source>
        <translation>Lisätty leikepöydälle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>VIRHE: Ei liitettävää</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Ei tilaa toiminnon suoritukselle.</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Ei oikeuksia toiminnon suoritukselle.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Broken Symlink!</source>
        <translation>Puuttuva symbolinen linkki!</translation>
    </message>
</context>
<context>
    <name>BookWindow</name>
    <message>
        <location filename="../bookwindow.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>Kirjanmerkit</translation>
    </message>
</context>
<context>
    <name>Home</name>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Home folder</source>
        <translation>Kotihakemisto</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Compress destination</source>
        <translation>Pakkauksen kohde</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Extract destination</source>
        <translation>Purkamisen kohde</translation>
    </message>
</context>
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../clipboard.cpp" line="10"/>
        <source>Clipboard</source>
        <translation>Leikepöytä</translation>
    </message>
</context>
<context>
    <name>Bookmarks</name>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>Kirjanmerkit</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>ToolsDialog</name>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Tools</source>
        <translation>Työkalut</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Add to Bookmarks</source>
        <translation>Lisää kirjanmerkki</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new folder</source>
        <translation>Luo uusi hakemisto</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new document</source>
        <translation>Luo uusi dokumentti</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Open terminal here</source>
        <translation>Avaa konsoli tässä</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Sort</source>
        <translation>Järjestä</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Paste from clipboard</source>
        <translation>Liitä leikepöydältä</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Cut from clipboard</source>
        <translation>Leikkaa leikepöydältä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>VIRHE: Ei liitettävää</translation>
    </message>
</context>
<context>
    <name>Share</name>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Share</source>
        <translation>Jaa</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via bluetooth</source>
        <translation>Jaa bluetoothilla</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via e-mail</source>
        <translation>Jaa sähköpostilla</translation>
    </message>
</context>
<context>
    <name>QtCopyDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1 of %2 completed</source>
        <translation>%1 valmis %2:sta</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>Varoitus (kopiointi)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source doesn&apos;t exist.</source>
        <translation>Lähdetiedostoa ei ole.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>No enough space for copy the file.</source>
        <translation>Ei tarpeeksi tilaa kopioinnille.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source file is a directory. Omitting source directory.</source>
        <translation>Lähdetiedosto on hakemisto. Lähdekansio ohitetaan.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source directory is a file. Omitting source file.</source>
        <translation>Lähdehakemisto on tiedosto. Lähdekansio ohitetaan.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Path to destination does not exist.</source>
        <translation>Kohteen polkua ei ole.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create destination directory.</source>
        <translation>Kohdehakemistoa ei voi luoda.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open source file. Please check permissions.</source>
        <translation>Lähdetiedostoa ei voi avata. Tarkista oikeudet.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open destination file. Please check permissions.</source>
        <translation>Kohdetiedostoa ei voi avata. Tarkista oikeudet.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Force: Cannot remove destination file.</source>
        <translation>Kohdetiedostoa ei voi poistaa.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create symbolic link targeting to source.</source>
        <translation>Symbolista linkkiä lähdetiedostoon ei voitu luoda.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot read source file.</source>
        <translation>Lähdetiedostoa ei voi lukea.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot write destination file.</source>
        <translation>Kohdetiedostoa ei voi kirjoittaa.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot remove source.</source>
        <translation>Lähdetiedostoa ei voi poistaa.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>100% of %1 (Done)</source>
        <translation>100% %1:sta (valmis)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copying...</source>
        <translation>Kopioidaan...</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1% of %2 (%3)</source>
        <translation>%1% %2:sta (%3)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>Kohde</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>QtOverwriteDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>Varoitus (kopiointi)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>Kohde</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Overwrite</source>
        <translation>Ylikirjoita</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination already exists.</source>
        <translation>Kohdetiedosto on jo olemassa.</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Preparing to delete %1 files</source>
        <translation>Valmistellaan %1:n tiedoston poistoa</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting %1</source>
        <translation>Poistetaan %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Error deleting %1</source>
        <translation>Virhe poistettaessa %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Delete Finished Ok</source>
        <translation>Poisto suoritettu Ok</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting files</source>
        <translation>Poistetaan tiedostoja</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Apply</source>
        <translation>Toteuta</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Home folder</source>
        <translation>Kotihakemisto</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Icons Style</source>
        <translation>Kuvaketyyli</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Text Editor</source>
        <translation>Tekstieditori</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable root access (restart needed)</source>
        <translation>Käytä root-oikeuksia (uudelleenkäynnistys tarvitaan)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show hidden files and folders</source>
        <translation>Näytä piilotiedostot ja -hakemistot</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show thumbnails for images</source>
        <translation>Näytä kuvat pienoiskuvina</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show details for files</source>
        <translation>Näytä tiedostojen tiedot</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Delete items from clipboard on Paste</source>
        <translation>Poista tiedosto leikepöydältä liitettäessä</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable multiselection</source>
        <translation>Salli monen tiedoston valitseminen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Auto select items in clipboard</source>
        <translation>Valitse leikepöydältä automaattisesti</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Orientation</source>
        <translation>Suunta</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Portrait</source>
        <translation>Pysty</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Landscape</source>
        <translation>Vaaka</translation>
    </message>
</context>
<context>
    <name>NewFolder</name>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Create folder</source>
        <translation>Luo hakemisto</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Enter new folder name</source>
        <translation>Uuden hakemiston nimi</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Accept</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cannot create folder. Try another name.</source>
        <translation>Hakemistoa ei voitu luoda. Kokeile toista nimeä.</translation>
    </message>
</context>
<context>
    <name>QtOtherDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Retry</source>
        <translation>Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Destination</source>
        <translation>Kohde</translation>
    </message>
</context>
<context>
    <name>Rename</name>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Renaming</source>
        <translation>Nimetään</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Enter new name</source>
        <translation>Anna uusi nimi</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Accept</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cannot rename. Try another name.</source>
        <translation>Ei voitu uudelleennimetä. Kokeile toista nimeä.</translation>
    </message>
</context>
<context>
    <name>AskDialog</name>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Deleting</source>
        <translation>Poistetaan</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Haluatko poistaa %1:n?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Haluatko poistaa valitut tiedostot?</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
</context>
<context>
    <name>Sort</name>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Sort</source>
        <translation>Järjestä</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Ascending</source>
        <translation>Nouseva</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Descending</source>
        <translation>Laskeva</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (A-Z)</source>
        <translation>Nimi (A-Z)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (Z-A)</source>
        <translation>Nimi (Z-A)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (olders first)</source>
        <translation>Päiväys (vanhin ensin)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (recents first)</source>
        <translation>Päiväys (uusin ensin)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (smallers first)</source>
        <translation>Koko (pienin ensin)</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (biggers first)</source>
        <translation>Koko (suurin ensin)</translation>
    </message>
</context>
<context>
    <name>NewDoc</name>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>New document</source>
        <translation>Uusi dokumentti</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Create</source>
        <translation>Luo</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter name for new document</source>
        <translation>Anna uuden dokumentin nimi</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter a valid file name</source>
        <translation>Anna sopiva nimi</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>The file already exists. Try another name</source>
        <translation>Tiedosto on jo olemassa. Kokeile toista nimeä</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cannot create the file. Check permissions</source>
        <translation>Tiedostoa ei voitu luoda. Tarkista oikeudet</translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Accept</source>
        <translation>Hyväksy</translation>
    </message>
</context>
<context>
    <name>CompressDlg</name>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compress</source>
        <translation>Pakkaa</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>File name</source>
        <translation>Tiedoston nimi</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compression</source>
        <translation>Pakkaus</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>Kohdehakemisto</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>The file already exists. Try another name.</source>
        <translation>Tiedosto on jo olemassa. Kokeile toista nimeä.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Ei tilaa toiminnon suoritukselle.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Ei oikeuksia toiminnon suoritukselle.</translation>
    </message>
</context>
<context>
    <name>Compress</name>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Compressing</source>
        <translation>Pakataan</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Adding %1...</source>
        <translation>Lisätään %1...</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>Toiminto suoritettu.</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>Unzip</name>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Extract files</source>
        <translation>Pura tiedostoja</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>Ei tilaa toiminnon suoritukselle.</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>Ei oikeuksia toiminnon suoritukselle.</translation>
    </message>
</context>
<context>
    <name>UnzipDlg</name>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Extract</source>
        <translation>Pura</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>Kohdehakemisto</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Keep existing files</source>
        <translation>Säilytä jo olevat tiedostot</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>Extract</name>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting</source>
        <translation>Puretaan</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting %1...</source>
        <translation>Puretaan %1...</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>Purkaminen suoritettu.</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Error extracting files. Incorrect password?</source>
        <translation>Virhe purettaessa tiedostoa. Virheellinen salasana?</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>About FileBox</source>
        <translation>Tietoja FileBoxista</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>File Manager for Maemo 5</source>
        <translation>Tiedostoselain Maemo 5:lle</translation>
    </message>
</context>
</TS>
